@@ -1,5 +1,5 @@
 """
-Copyright (c) 2021 The Python Packaging Authority
+Copyright (c) 2022 The Python Packaging Authority
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -19,22 +19,11 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-
-__version__ = '0.1.1'
+__version__ = '1.0.0'
 __title__ = 'MusicKuwo'
 __author__ = 'Xiaocaicai'
 __author_email__ = 'xiaocaicai_email@sina.com'
-__description__ = 'Kuwo music Python API package.'
-__url__ = 'https://github.com/xiaocaicai-github/MusicKuwo/'
-__all__ = ['RequestError', 'DownloadFile', 'SearchPrompt', 'Search']
+__description__ = 'A kuwo music python api package.'
+__url__ = 'https://github.com/XiaocaicaiGithub/MusicKuwo/'
 
-from sys import version
-
-from MusicKuwo.Errors import *
-
-PythonVersion = version[0:5]
-if PythonVersion[0] != '3':
-    raise PythonVersionError(
-        F'Your Python version is {PythonVersion}, but this module only applies to Python3 versions.')
-
-from MusicKuwo.Core import DownloadFile, SearchPrompt, Search
+from MusicKuwo.Core import SearchMusic, SearchArtist, SearchHints
